Struct ownedbytes::OwnedBytes[][src]

pub struct OwnedBytes { /* fields omitted */ }
An OwnedBytes simply wraps an object that owns a slice of data and exposes this data as a static slice.

The backing object is required to be StableDeref.

Implementations

Creates an empty OwnedBytes.

Creates an OwnedBytes intance given a StableDeref object.

creates a fileslice that is just a view over a slice of the data.

Returns the underlying slice of data. Deref and AsRef are also available.

Returns the len of the slice.

Splits the OwnedBytes into two OwnedBytes (left, right).

Left will hold split_len bytes.

This operation is cheap and does not require to copy any memory. On the other hand, both left and right retain a handle over the entire slice of memory. In other words, the memory will only be released when both left and right are dropped.

Splits the right part of the OwnedBytes at the given offset.

self is truncated to split_len, left with the remaining bytes.

Returns true iff this OwnedBytes is empty.

Drops the left most advance_len bytes.

See also .clip(clip_len: usize)).

Reads an u8 from the OwnedBytes and advance by one byte.

Reads an u64 encoded as little-endian from the OwnedBytes and advance by 8 bytes.